@@ -31,11 +31,11 @@ fn trait_with_castom_constructor_and_instance() {
 
     let injector = crate::Injector::new(containers);
 
-    let obj = injector.lock().unwrap().get_new_instance::<Box<dyn TextGetter>>().unwrap();
+    let obj = injector.write().unwrap().get_new_instance::<Box<dyn TextGetter>>().unwrap();
     assert_eq!(obj.get(), "test 1".to_string());
 
-    let obj = injector.lock().unwrap().get_singletone::<Box<dyn TextGetter>>().unwrap();
-    assert_eq!(obj.lock().unwrap().get(), "test 2".to_string());
+    let obj = injector.write().unwrap().get_singletone::<Box<dyn TextGetter>>().unwrap();
+    assert_eq!(obj.read().unwrap().get(), "test 2".to_string());
 }
 
 #[test]
@@ -50,9 +50,9 @@ fn unconfigured_trait_with_castom_constructor_and_instance() {
 
     let injector = crate::Injector::new(containers);
 
-    let obj = injector.lock().unwrap().get_new_instance::<Box<dyn TextGetter>>().unwrap();
+    let obj = injector.write().unwrap().get_new_instance::<Box<dyn TextGetter>>().unwrap();
     assert_eq!(obj.get(), "test 1".to_string());
 
-    let obj = injector.lock().unwrap().get_singletone::<Box<dyn TextGetter>>().unwrap();
-    assert_eq!(obj.lock().unwrap().get(), "test 2".to_string());
+    let obj = injector.write().unwrap().get_singletone::<Box<dyn TextGetter>>().unwrap();
+    assert_eq!(obj.read().unwrap().get(), "test 2".to_string());
 }
\ No newline at end of file
