@@ -30,14 +30,14 @@ fn trait_with_castom_instance() {
 
     let injector = crate::Injector::new(containers);
 
-    let obj = injector.lock().unwrap().get_singletone::<Box<dyn TextGetter>>().unwrap();
-    assert_eq!((*obj.lock().unwrap()).get(), "test".to_string());
+    let obj = injector.write().unwrap().get_singletone::<Box<dyn TextGetter>>().unwrap();
+    assert_eq!((*obj.read().unwrap()).get(), "test".to_string());
 
-    let obj = injector.lock().unwrap().get_new_instance::<Box<dyn TextGetter>>().unwrap();
+    let obj = injector.write().unwrap().get_new_instance::<Box<dyn TextGetter>>().unwrap();
     assert_eq!(obj.get(), "".to_string());
 
-    let obj = injector.lock().unwrap().get_singletone::<Box<dyn TextGetter>>().unwrap();
-    assert_eq!((*obj.lock().unwrap()).get(), "test".to_string());
+    let obj = injector.write().unwrap().get_singletone::<Box<dyn TextGetter>>().unwrap();
+    assert_eq!((*obj.read().unwrap()).get(), "test".to_string());
 }
 
 #[test]
@@ -49,8 +49,8 @@ fn unconfigured_trait_with_castom_instance_singletone_instance() {
 
     let injector = crate::Injector::new(containers);
 
-    let obj = injector.lock().unwrap().get_singletone::<Box<dyn TextGetter>>().unwrap();
-    assert_eq!((*obj.lock().unwrap()).get(), "test".to_string());
+    let obj = injector.write().unwrap().get_singletone::<Box<dyn TextGetter>>().unwrap();
+    assert_eq!((*obj.read().unwrap()).get(), "test".to_string());
 }
 
 #[test]
@@ -63,6 +63,6 @@ fn unconfigured_trait_with_castom_instance_new_instance_panic() {
 
     let injector = crate::Injector::new(containers);
 
-    let obj = injector.lock().unwrap().get_new_instance::<Box<dyn TextGetter>>().unwrap();
+    let obj = injector.write().unwrap().get_new_instance::<Box<dyn TextGetter>>().unwrap();
     assert_eq!(obj.get(), "test".to_string());
 }
\ No newline at end of file
