@@ -19,14 +19,14 @@ fn type_with_castom_instance() {
 
     let injector = crate::Injector::new(containers);
 
-    let obj = injector.lock().unwrap().get_singletone::<StructWithCustomInstance>().unwrap();
-    assert_eq!((*obj.lock().unwrap()).string, "test".to_string());
+    let obj = injector.write().unwrap().get_singletone::<StructWithCustomInstance>().unwrap();
+    assert_eq!((*obj.read().unwrap()).string, "test".to_string());
 
-    let obj = injector.lock().unwrap().get_new_instance::<StructWithCustomInstance>().unwrap();
+    let obj = injector.write().unwrap().get_new_instance::<StructWithCustomInstance>().unwrap();
     assert_eq!(obj.string, "".to_string());
 
-    let obj = injector.lock().unwrap().get_singletone::<StructWithCustomInstance>().unwrap();
-    assert_eq!((*obj.lock().unwrap()).string, "test".to_string());
+    let obj = injector.write().unwrap().get_singletone::<StructWithCustomInstance>().unwrap();
+    assert_eq!((*obj.read().unwrap()).string, "test".to_string());
 }
 
 #[test]
@@ -38,8 +38,8 @@ fn unconfigured_type_with_castom_instance_singletone_instance() {
 
     let injector = crate::Injector::new(containers);
 
-    let obj = injector.lock().unwrap().get_singletone::<StructWithCustomInstance>().unwrap();
-    assert_eq!((*obj.lock().unwrap()).string, "test".to_string());
+    let obj = injector.write().unwrap().get_singletone::<StructWithCustomInstance>().unwrap();
+    assert_eq!((*obj.read().unwrap()).string, "test".to_string());
 }
 
 #[test]
@@ -52,6 +52,6 @@ fn unconfigured_type_with_castom_instance_new_instance_panic() {
 
     let injector = crate::Injector::new(containers);
 
-    let obj = injector.lock().unwrap().get_new_instance::<StructWithCustomInstance>().unwrap();
+    let obj = injector.write().unwrap().get_new_instance::<StructWithCustomInstance>().unwrap();
     assert_eq!(obj.string, "".to_string());
 }
\ No newline at end of file
